/*
 * CrossTalk.c
 *
 *  Created on: May 1, 2012
 *      Author: Brenda Javornik (e-mail: brendaj (at) nwra.com)
 */


#include "Constants.h"
#include "utilities.h"
#include "matrix.h"
#include "Scatterer.h"

static bool xtalk = false;  ///> Single instance of crosstalk flag.

bool getCrossTalk() {
	return xtalk;
}

void setCrossTalk() {
	xtalk = true;
}

void clearCrossTalk() {
	xtalk = false;
}

/**
 * Multipy for crosstalk
 * @param[in] K Matrix K, should be K*
 * @param[in] nu current value of parameter nu
 * @param[in] Nz size of the z-dimension
 * @returns new Matrix containing \f$ \nu K^{v_{\beta}}(k) \f$  for \f$ \beta \neq \alpha \f$
 * where \f$ \alpha \f$ is scatterer of interest.
 */
MATRIX multipyForCrosstalk(MATRIX K, Float nu, int Nz) {
//	example usage: tdK2piCC2 = multipyForCrosstalk(tdK2piCC, getNu()->currentValue, Nz);
   MATRIX mK;

   int scatIdx; // integer representing the scatterer of interest
   scatIdx = getScatIndex();
   mK = scaleNonScatterer(K, nu, scatIdx, Nz, MAX_ALPHA);
   // use caution, because the matrices are stored in row-major order.

   return mK;
}
