/*
 * OneMatrix.c
 *
 *  Created on: Oct 13, 2010
 *      Author: Brenda Javornik (e-mail: brendaj (at) nwra.com)
 */
#include "utilities.h"
#include "matrix.h"
#include "ProblemDimension.h"
#include "Scatterer.h"
#include "OneMatrix.h"

/**
 * Construct matrix of 1's with dimensions determined by Nz of input kernels
 * @param[in] Nz Z-dimension of input kernels
 * @return MATRIX of 1's.  There is a single 'One' matrix.
 */
MATRIX *GetOne(int Nz) {
	static MATRIX One;
	static bool set = false;
	int a, a2, z;
	FloatComplex *zp;
	int idx;
	int NAlpha;

	if (set) {
		return &One;
	}

	if (getProblemDimension() == PDC.D5) {
		NAlpha = 3;
	} else {
		NAlpha = 1;
	}
	One = newComplexMatrix(Nz*NAlpha, NAlpha);
	zp = One.data;
	// if dim == 5 construct:
	// [1, 0, 0; 0, 1, 0; 0, 0, 1]
	// else if dim == 3 construct
	// [1]
	// for each column
	/* original code */
	FloatComplex value;
	for (a = 0; a < NAlpha; a++) {
		// for each row
		for (a2 = 0; a2 < NAlpha; a2++) {
			if (a == a2) value = 1.0 + 0.0*I;
			else value = 0.0 + 0.0*I;
			for (z = 0; z < Nz; z++) {
				//idx = ROW_MAJOR_IDX(R, C, NCOL);
				idx = ROW_MAJOR_IDX(a2*Nz+z, a, NAlpha);
				zp[idx] = value;
			}
		}
	}

	set = TRUE;
	return &One;
}

void DestroyOne() {
	MATRIX *One;
	One = GetOne(0);
	freeMatrix(*One);
}
