/*
 * WeightSpread.c
 *
 *  Created on: May 3, 2013
 *      Author: Brenda Javornik (e-mail: brendaj (at) nwra.com)
 */

#include "Constants.h"
#include "utilities.h"
#include "matrix.h"
#include "Scatterer.h"

static bool wSpreadLSQR = false;  ///> Single instance of flag to control the
                              ///> spread of the weights.

static bool wSpreadCLSQR = false;  ///> Single instance of flag to control the
                              ///> spread of the weights.

/**
 * Returns true if controlling the spread of the weights; false otherwise
 */
bool getWeightSpread() {
	return wSpreadLSQR;
}

/**
 * Set the indicator and control for the spread of the weights.
 */
void setWeightSpread() {
	wSpreadLSQR = true;
}

/**
 * Clear the indicator and don't control for the spread of the weights.
 */
void clearWeightSpread() {
	wSpreadLSQR = false;
}



/**
 * Returns true if controlling the spread of the weights; false otherwise
 */
bool getWeightSpreadCLSQR() {
	return wSpreadCLSQR;
}

/**
 * Set the indicator and control for the spread of the weights.
 */
void setWeightSpreadCLSQR() {
	wSpreadCLSQR = true;
}

/**
 * Clear the indicator and don't control for the spread of the weights.
 */
void clearWeightSpreadCLSQR() {
	wSpreadCLSQR = false;
}

/**
 * Add epsilon to each diagonal element of matrix for WeightSpread
 * @param[in] A Matrix A(k)
 * @param[in] epsilon current value of parameter epsilon.
 * NOTE: assume epsilon is multiplied by (1/N).
 */
void addForWeightSpread(MATRIX *A, Float epsilon) {
   addToDiagonal(A, epsilon);
   // use caution, because the matrices are stored in row-major order.
}


